# Grammar Fix Plan (absorbed)

See [docs/_archive/GRAMMAR_FIX_PLAN.md](../_archive/GRAMMAR_FIX_PLAN.md). Current status: [REF_22_PROJECT.md](../REF_22_PROJECT.md), [REF_13_ARCH.md](../REF_13_ARCH.md).
